==> apeman-commons-logging-1.3.0.tgz: package/ci/build.js <==
#!/usr/bin/env node

/**
 * Build this project
 */

"use strict";

process.chdir(__dirname + '/..');

var coz = require('coz'),
    path = require('path'),
    async = require('async'),
    tasking = require('apeman-dev-commons-tasking'),
    buds = require('apeman-tmpl-contrib-official/lib/commons');

var pkg = require('../package.json');

tasking.runTasks([
    function (callback) {
        coz.render([
            'lib/**/.*.bud',
            'test/**/.*.bud'
        ], callback);
    },
    function (callback) {
        buds.render({
            pkg: pkg,
            modules: [
                {name: 'ConsoleLogger'},
                {name: 'MessageFormatter'},
                {name: 'apemanAppLogger'},
                {name: 'apemanUiLogger'}
            ],
            usages: [
                {
                    title: 'Console Logger',
                    description: 'Create an instance and emit ansi-colored log to stdout/stderr.',
                    example: 'docs/examples/console-logger-example.js'
                },
                {
                    title: 'Message Formatter',
                    description: 'Create an instance and format message.',
                    example: 'docs/examples/message-format-eample.js'
                },
                {
                    title: 'Logger for apeman app',
                    description: 'Create a logger instance for apeman app packages',
                    example: 'docs/examples/apeman-app-logger-example.js'
                },
                {
                    title: 'Logger for apeman ui',
                    description: 'Create a logger instance for apeman ui packages',
                    example: 'docs/examples/apeman-ui-logger-example.js'
                }
            ],
            see: {
                'colorprint': "https://www.npmjs.com/package/colorprint"
            }
        }, callback);
    }
], true);

==> apeman-commons-logging-2.0.0.tgz: package/ci/build.js <==
#!/usr/bin/env node

/**
 * Build this project
 */

"use strict";

process.chdir(__dirname + '/..');

var coz = require('coz'),
    path = require('path'),
    tasking = require('apeman-dev-commons-tasking'),
    buds = require('apeman-tmpl-contrib-official/lib/commons');

var pkg = require('../package.json');

tasking.runTasks([
    function (callback) {
        coz.render([
            'lib/**/.*.bud',
            'test/**/.*.bud'
        ], callback);
    },
    function (callback) {
        buds.render({
            pkg: pkg,
            modules: [
                {name: 'ConsoleLogger'},
                {name: 'MessageFormatter'},
                {name: 'apemanAppLogger'},
                {name: 'apemanUiLogger'}
            ],
            usages: [
                {
                    title: 'Console Logger',
                    description: 'Create an instance and emit ansi-colored log to stdout/stderr.',
                    example: 'doc/examples/console-logger-example.js'
                },
                {
                    title: 'Message Formatter',
                    description: 'Create an instance and format message.',
                    example: 'doc/examples/message-format-eample.js'
                },
                {
                    title: 'Logger for apeman app',
                    description: 'Create a logger instance for apeman app packages',
                    example: 'doc/examples/apeman-app-logger-example.js'
                },
                {
                    title: 'Logger for apeman ui',
                    description: 'Create a logger instance for apeman ui packages',
                    example: 'doc/examples/apeman-ui-logger-example.js'
                }
            ],
            see: {
                'colorprint': "https://www.npmjs.com/package/colorprint"
            }
        }, callback);
    }
], true);
